@@ -28,9 +28,9 @@ Brandom <- function(theta0,v0,w,b0,chol=NULL,mult=0)
     ## tirer aleatoirement
     if(any(vbb!=0))
     {
-        ch <- chol(vbb)
-        ch <- t(ch)
-        br <- bb + ch %*% rnorm(length(bb))
+        ##ch <- chol(vbb)
+        ##ch <- t(ch)
+        br <- rmvnorm(n=1,mean=bb,sigma = vbb) #bb + ch %*% rnorm(length(bb))
     }
     else
     {
@@ -60,22 +60,36 @@ Brandom <- function(theta0,v0,w,b0,chol=NULL,mult=0)
             {
                 if(mult==0) # cas general
                 {
-                    nea <- (-1+sqrt(1+8*nvc[k]))/2
-                    chea <- matrix(0,nrow=nea,ncol=nea)
-                    chea[upper.tri(chea,diag=TRUE)] <- b[chol[[k]]]
-                    v <- t(chea)%*%chea
-                    
-                    b[chol[[k]]] <- v[upper.tri(v,diag=TRUE)]            
+                    if(names(chol)[k] == "diag")
+                    {
+                        b[chol[[k]]] <- b[chol[[k]]]^2
+                    }
+                    else
+                    {
+                        nea <- (-1+sqrt(1+8*nvc[k]))/2
+                        chea <- matrix(0,nrow=nea,ncol=nea)
+                        chea[upper.tri(chea,diag=TRUE)] <- b[chol[[k]]]
+                        v <- t(chea)%*%chea
+                        
+                        b[chol[[k]]] <- v[upper.tri(v,diag=TRUE)]
+                    }
                 }
         
                 if(mult==1) # cas multlcmm : mettre 1 pour la premiere variance
                 {
-                    nea <- (-1+sqrt(1+8*(nvc[k]+1)))/2
-                    chea <- matrix(0,nrow=nea,ncol=nea)
-                    chea[upper.tri(chea,diag=TRUE)] <- c(1,b[chol[[k]]])
-                    v <- t(chea)%*%chea
-                    
-                    b[chol[[k]]] <- v[upper.tri(v,diag=TRUE)][-1]
+                    if(names(chol)[k] == "diag")
+                    {
+                        b[chol[[k]]] <- b[chol[[k]]]^2
+                    }
+                    else
+                    {
+                        nea <- (-1+sqrt(1+8*(nvc[k]+1)))/2
+                        chea <- matrix(0,nrow=nea,ncol=nea)
+                        chea[upper.tri(chea,diag=TRUE)] <- c(1,b[chol[[k]]])
+                        v <- t(chea)%*%chea
+                        
+                        b[chol[[k]]] <- v[upper.tri(v,diag=TRUE)][-1]
+                    }
                 }
             }
         }
