@@ -1,3 +1,5 @@
+#' @export
+#'
 VarCovRE.lcmm <- function(Mod)
 {
   if(missing(Mod)) stop("The model should be specified")
@@ -146,5 +148,3 @@ VarCovRE.lcmm <- function(Mod)
   return(invisible(Results))
 
 }
-
-VarCovRE <- function(Mod) UseMethod("VarCovRE")
