@@ -1,10 +1,17 @@
-
+#' @export
 fitY.lcmm <- function(x)
     {
         if(missing(x)) stop("The model should be specified")
         if(!inherits(x,"lcmm")) stop("Use with 'lcmm' objects only")
 
-        data <- eval(x$call$data)
+        if(!is.null(x$data))
+        {
+            data <- x$data
+        }
+        else
+        {
+            data <- eval(x$call$data)
+        }
 
         if(!isTRUE(all.equal(as.character(x$call$subset),character(0))))
             {
@@ -37,6 +44,3 @@ fitY.lcmm <- function(x)
         return(res)
     }
 
-
-
-fitY <- function(x) UseMethod("fitY")
