@@ -1,6 +1,6 @@
 #' @export
 #'
-predictL.Jointlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
+predictL.Jointlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE, predRE = NULL, predCor = NULL, ...)
 {
 if(missing(newdata)) stop("The argument newdata should be specified")
 if(missing(x)) stop("The argument x should be specified")
@@ -14,6 +14,37 @@ if (!inherits(newdata, "data.frame")) stop("newdata should be a data.frame objec
 #if(missing(var.time)) stop("missing argument 'var.time'")
 #if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
 
+if(!is.null(predRE))
+{
+    if(confint == TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+    if(sum(x$idea) == 0) stop("No random effects are defined in the model")
+    if(!inherits(predRE, "data.frame")) stop("predRE should be a data.frame")
+    if(nrow(predRE) != x$ng) stop("predRE should contain as many rows as latent classes")
+        
+    if(!("class" %in% colnames(predRE)))
+    {
+        oldnames <- colnames(predRE)
+        predRE <- data.frame(predRE, class = 1:x$ng)
+        colnames(predRE) <- c(oldnames, "class")
+    }
+    else
+    {
+        predRE <- predRE[order(predRE$class),]
+    }
+    
+    namesRE <- colnames(x$predRE)[-1]
+    if(!all(namesRE %in% colnames(predRE))) stop(paste("predRE requires the following columns : ", paste(namesRE, collapse = " ")))
+    
+    predRE <- t(as.matrix(predRE[, namesRE, drop = FALSE]))
+}
+
+if(!is.null(predCor))
+{
+    if(confint==TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+    if(x$N[7] == 0) stop("No correlation is defined in the model")
+    if(ncol(predCor) != x$ng) stop("predCor should contain as many columns as latent classes")
+}
+
 call_fixed <- x$call$fixed[3]
 if(is.null(x$call$random)) {call_random <- -1} else call_random <- x$call$random[2]
 if(is.null(x$call$classmb)) {call_classmb <- -1} else call_classmb <- x$call$classmb[2]
@@ -214,6 +245,10 @@ if(!is.null(na.action)){
         times <- times[-na.action]
 }
 
+        if(!is.null(predCor)){
+            if(nrow(predCor) != nrow(newdata1)) stop(paste("predCor should be of length", nrow(newdata1), "(number of available data in newdata)"))
+        }
+        
         ## create one data frame for each formula (useful with factors)
         newdata1fixed <- newdata1
         for(v in colnames(newdata1fixed))
@@ -322,7 +357,7 @@ if(id.X_mixture == 1)
 		if((colnames(X_mixture)[i] %in% colnames(newdata1))==FALSE)
                     {
 			newdata1 <- cbind(newdata1,X_mixture[,i])
-                        newnames <-- c(newnames,colnames(X_mixture)[i])
+                        newnames <- c(newnames,colnames(X_mixture)[i])
                         colnames(newdata1) <- newnames
 		}
 	}
@@ -331,7 +366,7 @@ if(id.X_random == 1){
 	for(i in 1:length(colnames(X_random))){
 		if((colnames(X_random)[i] %in% colnames(newdata1))==FALSE){
 			newdata1 <- cbind(newdata1,X_random[,i])
-                        newnames <-- c(newnames,colnames(X_random)[i])
+                        newnames <- c(newnames,colnames(X_random)[i])
                         colnames(newdata1) <- newnames
 		}	 
 	}
@@ -340,7 +375,7 @@ if(id.X_classmb == 1){
 	for(i in 1:length(colnames(X_classmb))){
 		if((colnames(X_classmb)[i] %in% colnames(newdata1))==FALSE){
 			newdata1 <- cbind(newdata1,X_classmb[,i])
-                        newnames <-- c(newnames,colnames(X_classmb)[i])
+                        newnames <- c(newnames,colnames(X_classmb)[i])
                         colnames(newdata1) <- newnames	 
 		}	
 	}
@@ -411,6 +446,7 @@ if(x$N[7]>0)
                 }
             
             
+        ## marginal prediction :
             Y<-matrix(0,length(newdata1[,1]),x$ng)
             for(g in 1:x$ng)
                 {
@@ -424,6 +460,46 @@ if(x$N[7]>0)
                         }
                 }
 
+
+    if(!is.null(predRE) | !is.null(predCor))
+    {
+        if(!is.null(predRE))
+        {
+            ## add subject-specific part to Y :
+            Z <- newdata1[, which(x$idea == 1), drop = FALSE]
+            
+            if(ncol(predRE) == 1)
+            {
+                Zu <- Z %*% as.numeric(predRE)
+            
+                Y <- sweep(Y, 1, Zu, "+")
+            }
+            else
+            {
+                Zu <- Z %*% predRE
+                
+                Y <- Y + Zu
+            }
+        }
+
+        if(!is.null(predCor))
+        {
+            Y <- Y + predCor
+        }
+        
+        ## result
+        if (x$ng==1){
+            colnames(Y) <- c("pred")
+        }
+        if (x$ng>1){
+            colnames(Y) <- c(paste("pred_class", 1:x$ng, sep = ""))
+        }
+        
+        res.list <- list(pred = Y, times = times)
+    }
+        else
+        {        
+
            ##extraction de Var(beta)
             Vbeta <- matrix(0,x$N[4],x$N[4])
             npm <- length(x$best)
@@ -517,7 +593,7 @@ if(confint==TRUE)
           res.list$pred <- Y
           res.list$times <- times
       }
-
+}
 }
 else
 {
