@@ -1,6 +1,6 @@
 #' @export
 #'
-predictL.lcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
+predictL.lcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE, predRE = NULL, predCor = NULL, ...)
 {
 if(missing(newdata)) stop("The argument newdata should be specified")
 if(missing(x)) stop("The argument x should be specified")
@@ -9,6 +9,38 @@ if (!inherits(x, "lcmm")) stop("use only with \"lcmm\" objects")
 if (!all(x$Xnames2 %in% c(colnames(newdata),"intercept"))) {
 stop(paste(c("newdata should at least include the following covariates: ","\n",x$Xnames2[-1]),collapse=" "))}
 if (!inherits(newdata, "data.frame")) stop("newdata should be a data.frame object")
+
+if(!is.null(predRE))
+{
+    if(confint == TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+    if(sum(x$idea) == 0) stop("No random effects are defined in the model")
+    if(!inherits(predRE, "data.frame")) stop("predRE should be a data.frame")
+    if(nrow(predRE) != x$ng) stop("predRE should contain as many rows as latent classes")
+        
+    if(!("class" %in% colnames(predRE)))
+    {
+        oldnames <- colnames(predRE)
+        predRE <- data.frame(predRE, class = 1:x$ng)
+        colnames(predRE) <- c(oldnames, "class")
+    }
+    else
+    {
+        predRE <- predRE[order(predRE$class),]
+    }
+    
+    namesRE <- x$Xnames[which(x$idea0 == 1)] #colnames(x$predRE)[-1] n'existe pas si thresholds
+    if(!all(namesRE %in% colnames(predRE))) stop(paste("predRE requires the following columns : ", paste(namesRE, collapse = " ")))
+    
+    predRE <- t(as.matrix(predRE[, namesRE, drop = FALSE]))
+}
+
+if(!is.null(predCor))
+{
+    if(confint==TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+    if(x$N[6] == 0) stop("No correlation is defined in the model")
+    if(ncol(predCor) != x$ng) stop("predCor should contain as many columns as latent classes")
+}
+
 #if(missing(var.time)) stop("missing argument 'var.time'")
 #if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
 
@@ -217,7 +249,10 @@ if(!is.null(na.action)){
         times <- times[-na.action]
 }
 
-
+    if(!is.null(predCor)){
+        if(nrow(predCor) != nrow(newdata1)) stop(paste("predCor should be of length", nrow(newdata1), "(number of available data in newdata)"))
+    }
+    
     ## create one data frame for each formula (useful with factors)
     newdata1fixed <- newdata1
     for(v in colnames(newdata1fixed))
@@ -416,7 +451,7 @@ if(x$N[6]>0)
    }
   }
   
-  
+  ## marginal prediction :
   Y<-matrix(0,length(newdata1[,1]),x$ng)
   colnames(Y) <- paste("class",1:x$ng,sep="") 
   for(g in 1:x$ng){
@@ -428,6 +463,47 @@ if(x$N[6]>0)
   }
   }
 
+    if(!is.null(predRE) | !is.null(predCor))
+    {
+        if(!is.null(predRE))
+        {
+            ## add subject-specific part to Y :
+            Z <- newdata1[, which(x$idea0 == 1), drop = FALSE]
+            
+            if(ncol(predRE) == 1)
+            {
+                Zu <- Z %*% as.numeric(predRE)
+                
+                Y <- sweep(Y, 1, Zu, "+")
+            }
+            else
+            {
+                Zu <- Z %*% predRE
+                
+                Y <- Y + Zu
+            }
+        }
+
+        ## add BM/AR
+        if(!is.null(predCor))
+        {
+            Y <- Y + predCor
+        }
+        
+        ## result
+        if (x$ng==1){
+            colnames(Y) <- c("pred")
+        }
+        if (x$ng>1){
+            colnames(Y) <- c(paste("pred_class", 1:x$ng, sep = ""))
+        }
+        
+        res.list <- list(pred = Y, times = times)
+    }
+    else
+    {
+
+    
   #extraction de Var(beta)
   Vbeta <- matrix(0,x$N[2],x$N[2])
   npm <- length(x$best)
@@ -513,7 +589,7 @@ if(x$N[6]>0)
           res.list$pred <- Y
           res.list$times <- times
       }
-
+}
 }
 else{
 cat("Output can not be produced since the program stopped abnormally.")
@@ -528,15 +604,14 @@ cat("Output can not be produced since the program stopped abnormally.")
 
 
 
-#' Class-specific marginal predictions in the latent process scale for
+#' Class-specific marginal or subject-specific predictions in the latent process scale for
 #' \code{lcmm}, \code{Jointlcmm} and \code{multlcmm} objects
 #' 
 #' This function provides a matrix containing the class-specific predicted
 #' trajectories computed in the latent process scale, that is the latent
 #' process underlying the curvilinear outcome(s), for a profile of covariates
-#' specified by the user. This function applies only to \code{lcmm} and
-#' \code{multlcmm} objects. The function \code{plot.predict} provides directly
-#' the plot of these class-specific predicted trajectories. The function
+#' specified by the user. This function applies only to \code{lcmm}, \code{multlcmm} and
+#' \code{Jointlcmm} objects.  The function
 #' \code{predictY} provides the class-specific predicted trajectories computed
 #' in the natural scale of the outcome(s).
 #' 
@@ -556,6 +631,15 @@ cat("Output can not be produced since the program stopped abnormally.")
 #' 'na.pass' or 'na.exclude' are not implemented in the current version.
 #' @param confint logical indicating if confidence should be provided. Default
 #' to FALSE.
+#' @param predRE optional data frame containing the predicted random effects
+#' in each latent class. If NULL (the default), marginal prediction are
+#' computed.If predRE is specified, subject-specific predictions
+#' are computed. 
+#' @param predCor optional matrix.
+#' If \code{predCor} is specified, the returned predictions include the
+#' correlation (BM or AR) part of the model. \code{predCor} should be a matrix
+#' with as many columns as latent classes and as many rows as newdata.
+#' In particular, predCor can be the result of a predictCor call.
 #' @param \dots further arguments to be passed to or from other methods.  They
 #' are ignored in this function.
 #' @return An object of class \code{predictL} with values :
@@ -566,8 +650,7 @@ cat("Output can not be produced since the program stopped abnormally.")
 #' 
 #' - \code{times} : the \code{var.time} variable from \code{newdata}
 #' @author Cecile Proust-Lima, Viviane Philipps
-#' @seealso \code{\link{plot.predict}}, \code{\link{predictY}},
-#' \code{\link{lcmm}}
+#' @seealso \code{\link{predictY}},\code{\link{predictRE}},\code{\link{predictYcond}}
 #' @examples
 #' 
 #' #### Prediction from a 2-class model with a Splines link function
@@ -592,4 +675,4 @@ cat("Output can not be produced since the program stopped abnormally.")
 #' 
 #' @export
 #' 
-predictL <- function(x,newdata,var.time,na.action=1,confint=FALSE,...) UseMethod("predictL")
+predictL <- function(x,newdata,var.time,na.action=1,confint=FALSE,predRE=NULL,predCor=NULL,...) UseMethod("predictL")
