@@ -1,6 +1,6 @@
 #' @export
 #'
-predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
+predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE, predRE = NULL, predCor = NULL, ...)
 {
  if(missing(newdata)) stop("The argument newdata should be specified")
  if(missing(x)) stop("The argument x should be specified")
@@ -12,6 +12,36 @@ predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
 # if(missing(var.time)) stop("missing argument 'var.time'")
 # if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
 
+if(!is.null(predRE))
+{
+    if(confint == TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+    
+    if(!inherits(predRE, "data.frame")) stop("predRE should be a data.frame")
+    if(nrow(predRE) != x$ng) stop("predRE should contain as many rows as latent classes")
+        
+    if(!("class" %in% colnames(predRE)))
+    {
+        oldnames <- colnames(predRE)
+        predRE <- data.frame(predRE, class = 1:x$ng)
+        colnames(predRE) <- c(oldnames, "class")
+    }
+    else
+    {
+        predRE <- predRE[order(predRE$class),]
+    }
+    
+    namesRE <- colnames(x$predRE)[-1]
+    if(!all(namesRE %in% colnames(predRE))) stop(paste("predRE requires the following columns : ", paste(namesRE, collapse = " ")))
+    
+    predRE <- t(as.matrix(predRE[, namesRE, drop = FALSE]))
+}
+ 
+if(!is.null(predCor))
+{
+    if(confint==TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+    if(x$N[7] == 0) stop("No correlation is defined in the model")
+    if(ncol(predCor) != x$ng) stop("predCor should contain as many columns as latent classes")
+}
  
  if(x$conv==1 | x$conv==2 | x$conv==3)
  { 
@@ -125,7 +155,10 @@ predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
       newdata1 <- newdata
   }
   
-
+  if(!is.null(predCor)){
+      if(nrow(predCor) != nrow(newdata1)) stop(paste("predCor should be of length", nrow(newdata1), "(number of available data in newdata)"))
+  }
+  
   ## create one data frame for each formula (useful with factors)
   newdata1fixed <- newdata1
   for(v in colnames(newdata1fixed))
@@ -313,7 +346,7 @@ predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
   }
 
 
-  
+  ## marginal prediction :
   Y<-matrix(0,length(newdata1[,1]),x$ng)
   colnames(Y) <- paste("class",1:x$ng,sep="")
   for(g in 1:x$ng)
@@ -328,8 +361,45 @@ predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
    }
   }
 
+    if(!is.null(predRE) | !is.null(predCor))
+    {
+        if(!is.null(predRE))
+        {
+            ## add subject-specific part to Y :
+            Z <- newdata1[, which(x$idea0 == 1), drop = FALSE]
+            
+            if(ncol(predRE) == 1)
+            {
+                Zu <- Z %*% as.numeric(predRE)
+                
+                Y <- sweep(Y, 1, Zu, "+")
+            }
+            else
+            {
+                Zu <- Z %*% predRE
+                
+                Y <- Y + Zu
+            }
+        }
+
+        if(!is.null(predCor))
+        {
+            Y <- Y + predCor
+        }
+        
+        ## result
+        if (x$ng==1){
+            colnames(Y) <- c("pred")
+        }
+        if (x$ng>1){
+            colnames(Y) <- c(paste("pred_class", 1:x$ng, sep = ""))
+        }
+        
+        res.list <- list(pred = Y, times = times)
+    }
+    else
+     {
   
-  ny <- length(x$Ynames)
 
   #extraction de Var(beta) 
   Vbeta <- matrix(0,x$N[3]-x$N[2]-x$N[1],x$N[3]-x$N[2]-x$N[1])
@@ -416,6 +486,7 @@ predictL.multlcmm <- function(x,newdata,var.time,na.action=1,confint=FALSE,...)
           res.list$pred <- Y
           res.list$times <- times
       }
+     }
  }
  else
  {
