@@ -2,7 +2,7 @@
 #' @rdname predictY
 #' @export
 #'
-predictY.Jointlcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndraws=2000,na.action=1,...)
+predictY.Jointlcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndraws=2000,na.action=1, predRE = NULL, predCor = NULL, ...)
 {
     if(missing(newdata)) stop("The argument newdata should be specified")
     if(missing(x)) stop("The argument x should be specified")
@@ -14,8 +14,43 @@ predictY.Jointlcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALS
     if ((methInteg==0)&(!(nsim %in% c(5,7,9,15,20,30,40,50)))) stop("For Gauss-Hermite integration method, 'nsim' should be either 5,7,9,15,20,30,40 or 50")
 #    if(missing(var.time)) stop("missing argument 'var.time'")
 #    if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
+    
+    if(!is.null(predRE))
+    {
+        if(x$linktype != -1) stop("Subject-specific predictions are not available for models including a link function")
+        if(sum(x$idea) == 0) stop("No random effects are defined in the model")
+        if(!inherits(predRE, "data.frame")) stop("predRE should be a data.frame")
+        if(nrow(predRE) != x$ng) stop("predRE should contain as many rows as latent classes")
+        if(draws==TRUE) stop("No confidence intervals are provided for subject-specific prediction")
+        
+        
+        if(!("class" %in% colnames(predRE)))
+        {
+            oldnames <- colnames(predRE)
+            predRE <- data.frame(predRE, class = 1:x$ng)
+            colnames(predRE) <- c(oldnames, "class")
+        }
+        else
+        {
+            predRE <- predRE[order(predRE$class),]
+        }
+        
+        namesRE <- colnames(x$predRE)[-1]
+        if(!all(namesRE %in% colnames(predRE))) stop(paste("predRE requires the following columns : ", paste(namesRE, collapse = " ")))
+        
+        predRE <- t(as.matrix(predRE[, namesRE, drop = FALSE]))
+    }
 
+    if(!is.null(predCor))
+    {
+        if(x$linktype != -1) stop("Subject-specific predictions are not available for models including a link function")
+        if(x$N[7] == 0) stop("No correlation is defined in the model")
+        if(draws==TRUE) stop("No confidence intervals are provided for subject-specific prediction")
 
+        if(ncol(predCor) != x$ng) stop("predCor should contain as many columns as latent classes")
+    }
+
+    
     if(x$conv==1 | x$conv==2 | x$conv==3)
         {
 
@@ -306,7 +341,10 @@ call_survival <- formula(paste("~",call_survival,sep=""))
                     times <- times[-na.action,,drop=FALSE]
                 }
             
-
+            if(!is.null(predCor)){
+                if(nrow(predCor) != nrow(newdata1)) stop(paste("predCor should be of length", nrow(newdata1), "(number of available data in newdata)"))
+            }
+            
             ## create one data frame for each formula (useful with factors)
             newdata1fixed <- newdata1
             for(v in colnames(newdata1fixed))
@@ -548,11 +586,37 @@ call_survival <- formula(paste("~",call_survival,sep=""))
                                 }
                         }
 
+                    if(!is.null(predRE))
+                    {
+                        ## add subject-specific part to Y :
+                        Z <- newdata1[, which(x$idea == 1), drop = FALSE]
+                        
+                        if(ncol(predRE) == 1)
+                        {
+                            Zu <- Z %*% as.numeric(predRE)
+                            
+                            Ypred <- sweep(Ypred, 1, Zu, "+")
+                        }
+                        else
+                        {
+                            Zu <- Z %*% predRE
+                            
+                            Ypred <- Ypred + Zu
+                        }
+                    }
+                    
+                    if(!is.null(predCor))
+                    {
+                        ## add BM/AR
+                        Ypred <- Ypred + predCor
+                    }
+
 
                     colnames(Ypred) <- paste("Ypred_class",1:x$ng,sep="")
                     if (x$ng==1) colnames(Ypred) <- "Ypred"
                     res <- Ypred
 
+
                     if(isTRUE(draws))
                         {
                             ##IC pour les predictions 
