@@ -18,6 +18,8 @@ predictY.lcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndr
                                         #if(missing(var.time)) stop("missing argument 'var.time'")
                                         #if(!(var.time %in% colnames(newdata))) stop("'var.time' should be included in newdata")
 
+    dots <- list(...)
+    if(("predRE" %in% names(dots)) | ("predCor" %in% names(dots))) stop("No subject-specific prediction can be computed with lcmm models")
 
     call_fixed <- x$call$fixed[3]
     if(is.null(x$call$random)) {call_random <- -1} else call_random <- x$call$random[2]
@@ -979,13 +981,14 @@ predictY.lcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndr
 
 #' Predictions (marginal and possibly subject-specific in some cases) of a \code{hlme},
 #' \code{lcmm}, \code{multlcmm} or \code{Jointlcmm} object in the natural scale
-#' of the longitudinal outcome(s) computed from a profile of covariates (marginal) or
-#' individual data (subject specific in case of \code{hlme}).
+#' of the longitudinal outcome(s) computed from a profile of covariates.
 #' 
 #' For \code{hlme} and \code{Jointlcmm} objects, the function computes the
 #' predicted values of the longitudinal marker (in each latent class of ng>1) for a
-#' specified profile of covariates.  For \code{lcmm} and \code{multlcmm}
-#' objects, the function computes predicted values in the natural scale of the
+#' specified profile of covariates.
+#' Marginal or subject-specific predictions can be obtained.
+#' For \code{lcmm} and \code{multlcmm} objects, only marginal prediction are 
+#' available, and the function computes predicted values in the natural scale of the
 #' outcomes for a specified profile of covariates. For linear and threshold
 #' links, the predicted values are computed analytically. For splines and Beta
 #' links, a Gauss-Hermite or Monte-Carlo integration are used to numerically
@@ -1028,12 +1031,19 @@ predictY.lcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndr
 #' only; if draws=TRUE, ndraws specifies the number of draws that should be
 #' generated to approximate the posterior distribution of the predicted values.
 #' By default, ndraws=2000.
-#' @param marg Optional boolean specifying whether the      
-#' predictions are marginal (the default) or subject-specific (marg=FALSE). marge=FALSE 
-#' only works with \code{hlme} objects.
-#' @param subject For a \code{hlme} object with marg=FALSE only, character specifying
-#' the name of the grouping strucuture. If NULL (the default), the same as in the model
-#' (argument x) will be used.
+#' @param predRE option only available for \code{hlme} or \code{Jointlcmm} models.
+#' If \code{predRE} is specified, the predictY function returns subject-specific predictions.
+#' If NULL, marginal predictions are computed.
+#' For subject-specific predictions, \code{predRE} should be a data frame
+#' with as many rows as latent classes
+#' containing the predicted random effects in each latent class.
+#' In particular, predRE can be the result of a predictRE call with classpredRE = TRUE.
+#' @param predCor option only available for \code{hlme} models and
+#' \code{Jointlcmm} models without any link function.
+#' If \code{predCor} is specified, the returned predictions include the
+#' correlation (BM or AR) part of the model. \code{predCor} should be a matrix
+#' with as many columns as latent classes and as many rows as newdata.
+#' In particular, predCor can be the result of a predictCor call.
 #' @param na.action Integer indicating how NAs are managed. The default is 1
 #' for 'na.omit'. The alternative is 2 for 'na.fail'. Other options such as
 #' 'na.pass' or 'na.exclude' are not implemented in the current version.
@@ -1073,8 +1083,7 @@ predictY.lcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndr
 #' 
 #' - \code{times} : the \code{var.time} variable from \code{newdata}
 #' @author Cecile Proust-Lima, Viviane Philipps, Sasha Cuau
-#' @seealso \code{\link{lcmm}}, \code{\link{multlcmm}}, \code{\link{hlme}},
-#' \code{\link{Jointlcmm}}
+#' @seealso \code{\link{predictYback}}
 #' @examples
 #' 
 #' 
