@@ -11,6 +11,11 @@ summary.multlcmm <- function(object,...)
       cat("General latent class mixed model", "\n")
     }
     cat("     fitted by maximum likelihood method", "\n")
+    if(inherits(x, "externVar")){
+      if(x$varest == "none") cat(" ** Parameter variance estimated without correction for primary model uncertainty **", "\n \n")
+      if(x$varest == "Hessian") cat(" ** Total parameter variance estimated using the Hessian of the joint likelihood **", "\n \n")
+      if(x$varest == "paramBoot") cat(" ** Total parameter variance estimated using parametric bootstrap **", "\n \n")
+    }
 
     cl <- x$call
     cl$B <- NULL
@@ -473,7 +478,6 @@ summary.multlcmm <- function(object,...)
                                paste(paste(rep(" ",max(maxch[2]-2,0)),collapse=""),"Se",sep=""),
                                paste(paste(rep(" ",max(maxch[3]-4,0)),collapse=""),"Wald",sep=""),
                                paste(paste(rep(" ",max(maxch[4]-7,0)),collapse=""),"p-value",sep=""))
-            if(inherits(x, "externVar")) colnames(tmp)[2] = paste(paste(rep(" ",max(maxch[2]-5,0)),collapse=""),"Se***",sep="")
             cat("\n")
             print(tmp,quote=FALSE,na.print="")
             cat("\n")
@@ -486,11 +490,7 @@ summary.multlcmm <- function(object,...)
                 {
                     cat(" ** coefficient not estimated but obtained from the others as minus the sum of them \n \n")
                 }
-            if(inherits(x, "externVar")){
-              if(x$varest == "none") cat(" *** total variance estimated witout correction for primary model uncertainty", "\n \n")
-              if(x$varest == "Hessian") cat(" *** total variance estimated through the Hessian of the joint likelihood", "\n \n")
-              if(x$varest == "paramBoot") cat(" *** total variance estimated through parametric bootstrap", "\n \n")
-            }
+
             
             return(invisible(tTable))
         }
