@@ -828,7 +828,7 @@
       double precision,dimension(nobs,ng)::     &
     pred_m_g,pred_ss_g
       double precision,dimension(ns,ng) ::PPI
-      double precision,dimension(ns*nea)::pred_RE
+      double precision,dimension(ns*nea*(1+ng))::pred_RE
       double precision,dimension(ns*nea*(nea+1)/2)::var_RE
 
 
@@ -1030,6 +1030,7 @@
 
             do k=1,nea
                pred_RE((i-1)*nea+k)=err2(k)
+               pred_RE(ns*nea + (i-1)*nea + k)=err2(k)
             end do
 
             !! var_RE = Var(b/Yi) = B - BZ'V^(-1)ZB
@@ -1195,7 +1196,8 @@
                      end do
                   end do
                   do k=1,nea
-                    pred_RE((i-1)*nea+k)=9999.d0
+                     pred_RE((i-1)*nea+k)=9999.d0
+                     pred_RE(ns*nea + (i-1)*ng*nea + (g-1)*nea + k) = 9999.d0
                   end do
                   goto 654
                end if
@@ -1237,7 +1239,8 @@
 
                do k=1,nea
                   pred_RE((i-1)*nea+k)=pred_RE((i-1)*nea+k)+ppi(i,g)*  &
-                  err2(k)
+                       err2(k)
+                  pred_RE(ns*nea + (i-1)*ng*nea + (g-1)*nea + k) = err2(k)
                end do
 
             end do
@@ -1298,7 +1301,7 @@
       double precision::thi,thj
       double precision, dimension(ns0,ng0) :: PPI
       double precision, dimension(npm0+nfix0)::btot
-      double precision, dimension(ns0*nea0), intent(out)::pred_RE
+      double precision, dimension(ns0*nea0*(1+ng0)), intent(out)::pred_RE
       double precision, dimension(ns0*nea0*(nea0+1)/2), intent(out)::var_RE
       double precision, dimension(nobs0) :: resid_m, resid_ss
       double precision, dimension(nobs0,ng0):: pred_m_g, pred_ss_g
